IF OBJECT_ID('[ApplicationDeploymentPlans]') IS NOT NULL
	DROP VIEW [ApplicationDeploymentPlans]
GO

CREATE VIEW [ApplicationDeploymentPlans]
AS

SELECT DP.[DeploymentPlan_Id],
       DP.[DeploymentPlan_Name],
	   A.[Application_Id],
	   A.[Application_Name],
	   AG.[ApplicationGroup_Id],
	   AG.[ApplicationGroup_Name],
	   E.[Environment_Id],
	   E.[Environment_Name],
       [Environment_Display_Sequence] = E.[Display_Sequence],
	   W.[Workflow_Id],
	   W.[Workflow_Name],
	   [Workflow_Step_Sequence] = WS.[Step_Sequence],
       [BuildStep_Indicator] = 'N',
	   DP.[AllowLocalChanges_Indicator],
       DP.[OtterScript_Bytes],
       [DeploymentPlan_Shared_Indicator] = CASE WHEN 
                                                    DP.[DeploymentPlan_Id] IN 
                                                         (SELECT [PlanId] FROM 
                                                            (SELECT [PlanId] = [DeploymentPlan_Id] FROM [WorkflowSteps]
                                                              UNION ALL 
                                                             SELECT [PlanId] = [Build_DeploymentPlan_Id] FROM [Workflows]) AS [AllPlanIds]
                                                        GROUP BY [PlanId]
                                                        HAVING COUNT([PlanId]) > 1)
                                                
                                                THEN 'Y'
                                                ELSE 'N'
                                            END
  FROM [ApplicationWorkflows] AW
       INNER JOIN [Workflows] W
	           ON W.[Workflow_Id] = AW.[Workflow_Id]
       INNER JOIN [WorkflowSteps] WS
	           ON WS.[Workflow_Id] = AW.[Workflow_Id]
	   INNER JOIN [Applications] A
	           ON A.[Application_Id] = AW.[Application_Id]
	   INNER JOIN [Environments] E
	           ON E.[Environment_Id] = WS.[Environment_Id]
	   INNER JOIN [DeploymentPlans] DP
	           ON DP.[DeploymentPlan_Id] = WS.[DeploymentPlan_Id]
        LEFT JOIN [ApplicationGroups] AG
		       ON AG.[ApplicationGroup_Id] = A.[ApplicationGroup_Id]
UNION ALL 
SELECT 
	   DP.[DeploymentPlan_Id],
       DP.[DeploymentPlan_Name],
	   A.[Application_Id],
	   A.[Application_Name],
	   AG.[ApplicationGroup_Id],
	   AG.[ApplicationGroup_Name],
	   NULL,
	   NULL,
       NULL,
	   W.[Workflow_Id],
	   W.[Workflow_Name],
	   NULL,
       [BuildStep_Indicator] = 'Y',
	   DP.[AllowLocalChanges_Indicator],
       DP.[OtterScript_Bytes],
       [DeploymentPlan_Shared_Indicator] = CASE WHEN 
                                                    DP.[DeploymentPlan_Id] IN 
                                                         (SELECT [PlanId] FROM 
                                                            (SELECT [PlanId] = [DeploymentPlan_Id] FROM [WorkflowSteps]
                                                              UNION ALL 
                                                             SELECT [PlanId] = [Build_DeploymentPlan_Id] FROM [Workflows]) AS [AllPlanIds]
                                                        GROUP BY [PlanId]
                                                        HAVING COUNT([PlanId]) > 1)
                                                
                                                THEN 'Y'
                                                ELSE 'N'
                                            END
  FROM [ApplicationWorkflows] AW
       INNER JOIN [Workflows] W
	           ON W.[Workflow_Id] = AW.[Workflow_Id]
	   INNER JOIN [Applications] A
	           ON A.[Application_Id] = AW.[Application_Id]
	   INNER JOIN [DeploymentPlans] DP
	           ON DP.[DeploymentPlan_Id] = W.[Build_DeploymentPlan_Id]
        LEFT JOIN [ApplicationGroups] AG
		       ON AG.[ApplicationGroup_Id] = A.[ApplicationGroup_Id]
GO