IF OBJECT_ID('[ConfigurationFileInstances_Extended]') IS NOT NULL DROP VIEW [ConfigurationFileInstances_Extended]
GO

CREATE VIEW [ConfigurationFileInstances_Extended] AS

SELECT CFI.[ConfigurationFile_Id]
      ,CFI.[Instance_Name]
      ,CFI.[Active_Indicator]
      ,CFI.[Environment_Id]
      ,E.[Environment_Name]
	  ,E.[Display_Sequence]

      ,CF.[Deployable_Id]
      ,CF.[FilePath_Text]
      ,[ConfigurationFile_Active_Indicator] = CF.[Active_Indicator]

      ,CF.[Application_Id]

      ,[LatestVersion_Version_Number] = CFV.[Version_Number]
      ,[LatestVersion_VersionNotes_Text] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[VersionNotes_Text] ELSE CFV_NonNull.[VersionNotes_Text] END
      ,[LatestVersion_File_Date] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[File_Date] ELSE CFV_NonNull.[File_Date] END
      ,[LatestVersion_File_Bytes] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[File_Bytes] ELSE CFV_NonNull.[File_Bytes] END
      ,[LatestVersion_CreatedOn_Date] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[CreatedOn_Date] ELSE CFV_NonNull.[CreatedOn_Date] END
      ,[LatestVersion_CreatedByUser_Name] = CASE WHEN CFV.[Null_Indicator] = 'N' THEN CFV.[CreatedBy_User_Name] ELSE CFV_NonNull.[CreatedBy_User_Name] END

      ,CFI.[Template_Indicator]
      ,CFI.[Template_Instance_Name]
      ,[Template_Instance_Count] = (    
                             SELECT CASE WHEN CFI.[Template_Indicator] = 'Y' THEN COUNT(*) ELSE NULL END
                             FROM [ConfigurationFileInstances] 
                             WHERE [ConfigurationFile_Id] = CFI.[ConfigurationFile_Id] 
                               AND [Active_Indicator] = 'Y'
                               AND [Template_Instance_Name] = CFI.[Instance_Name]
                               )
	  ,CFI.[TransformType_Code]

  FROM [ConfigurationFileInstances] CFI
       INNER JOIN [ConfigurationFiles] CF
               ON CFI.[ConfigurationFile_Id] = CF.[ConfigurationFile_Id]
        LEFT JOIN [Deployables] D
               ON D.[Deployable_Id] = CF.[Deployable_Id]

	    LEFT JOIN (SELECT [ConfigurationFile_Id],
		                  [Instance_Name],
						  [Latest_Version_Number] = MAX(CFV_Inner.[Version_Number]),
						  [Last_NonNull_Version] = (SELECT MAX(CFV_Inner_Inner.[Version_Number])
						                              FROM [ConfigurationFileVersions] CFV_Inner_Inner
													 WHERE CFV_Inner_Inner.[ConfigurationFile_Id] = CFV_Inner.[ConfigurationFile_Id]
													   AND CFV_Inner_Inner.[Instance_Name] = CFV_Inner.[Instance_Name]
													   AND CFV_Inner_Inner.[Version_Number] < MAX(CFV_Inner.[Version_Number])
													   AND CFV_Inner_Inner.[Null_Indicator] = 'N')
		             FROM [ConfigurationFileVersions] CFV_Inner
					GROUP BY [ConfigurationFile_Id], [Instance_Name]) CFV_Latest
			   ON CFV_Latest.[ConfigurationFile_Id] = CFI.[ConfigurationFile_Id]
			  AND CFV_Latest.[Instance_Name] = CFI.[Instance_Name]

		LEFT JOIN [ConfigurationFileVersions] CFV
		       ON CFV.[ConfigurationFile_Id] = CFI.[ConfigurationFile_Id]
			  AND CFV.[Instance_Name] = CFI.[Instance_Name]
			  AND CFV.[Version_Number] = CFV_Latest.[Latest_Version_Number]

		LEFT JOIN [ConfigurationFileVersions] CFV_NonNull
		       ON CFV.[Null_Indicator] = 'Y'
			  AND CFV_NonNull.[ConfigurationFile_Id] = CFI.[ConfigurationFile_Id]
			  AND CFV_NonNull.[Instance_Name] = CFI.[Instance_Name]
			  AND CFV_NonNull.[Version_Number] = CFV_Latest.[Last_NonNull_Version]

        LEFT JOIN [Environments] E
               ON E.[Environment_Id] = CFI.[Environment_Id]
GO
