EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Artifacts_CreateOrReplaceArtifact',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a reference to an artifact in the artifact library.'
GO


IF OBJECT_ID('[Artifacts_CreateOrReplaceArtifact]') IS NOT NULL DROP PROCEDURE [Artifacts_CreateOrReplaceArtifact]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Artifacts_CreateOrReplaceArtifact]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
	@Deployable_Id INT,
	@Artifact_Name VARCHAR(50),
	@Execution_Id INT,
	@Artifact_Path VARCHAR(250)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Build_Id INT
	SELECT @Build_Id = [Build_Id]
	  FROM [Builds_Extended]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number
	   AND [Build_Number] = @Build_Number

	DELETE [BuildArtifacts]
	 WHERE [Build_Id] = @Build_Id
       AND (
             (@Deployable_Id IS NULL AND [Deployable_Id] IS NULL)
             OR
             ([Deployable_Id] = @Deployable_Id)
           )
	   AND [Artifact_Name] = @Artifact_Name

	INSERT INTO [BuildArtifacts]
	(
		[Build_Id],
		[Deployable_Id],
		[Artifact_Name],
		[Execution_Id],
		[Created_Date],
		[Artifact_Path]
	)
	VALUES
	(
		@Build_Id,
		@Deployable_Id,
		@Artifact_Name,
		@Execution_Id,
		GETUTCDATE(),
		@Artifact_Path
	)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Artifacts_CreateOrReplaceArtifact] TO [BuildMasterUser_Role]
