EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ChangeControls_CreateOrUpdateChangeControl',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ChangeControl_Id',
    /* Description_Text        */ 'Creates a new change control, or updates an existing one.'
GO

IF OBJECT_ID('[ChangeControls_CreateOrUpdateChangeControl]') IS NOT NULL DROP PROCEDURE [ChangeControls_CreateOrUpdateChangeControl]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ChangeControls_CreateOrUpdateChangeControl]
(
	@ChangeControl_Id INT = NULL OUT,
	@ChangeControl_Name VARCHAR(100),
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Group_Name VARCHAR(100),
	@Description_Text VARCHAR(MAX),
	@Principal_Name USERNAME,
	@PrincipalType_Code CHAR(1),
	@PerformanceType_Code CHAR(1),
	@Active_Indicator YNINDICATOR,
	@Environments_Csv VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
BEGIN TRANSACTION

	DECLARE @Release_Id INT
	SELECT @Release_Id = [Release_Id]
	  FROM [Releases]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number

    IF @ChangeControl_Id IS NULL
    BEGIN
    
        INSERT INTO [ChangeControls]
        (
			[Release_Id]
	       ,[ChangeControl_Name]
	       ,[Group_Name]
	       ,[Description_Text]
	       ,[Principal_Name]
	       ,[PrincipalType_Code]
	       ,[PerformanceType_Code]
	       ,[CreatedBy_User_Name]
	       ,[CreatedOn_Date]
	       ,[ModifiedBy_User_Name]
	       ,[ModifiedOn_Date]
	       ,[Active_Indicator]
        )
        VALUES
        (
	         @Release_Id
	        ,@ChangeControl_Name
	        ,@Group_Name
	        ,@Description_Text
	        ,@Principal_Name
	        ,@PrincipalType_Code
	        ,@PerformanceType_Code
	        ,dbo.Session_GetUserName()
	        ,GETUTCDATE()
	        ,dbo.Session_GetUserName()
	        ,GETUTCDATE()
	        ,@Active_Indicator
        )
        
        SET @ChangeControl_Id = SCOPE_IDENTITY()
        
        INSERT INTO [ChangeControlEnvironments]
		(
			[ChangeControl_Id],
			[Environment_Id]
		)
		SELECT @ChangeControl_Id,
			   CAST(CSV.[Value_Text] AS INT)
		  FROM dbo.CsvToTable(@Environments_Csv, ',') CSV
        
        EXEC [Events_RaiseEvent] 'CCTNEW', @Application_Id, @ChangeControl_Id
    
    END
    ELSE
    BEGIN
    
        UPDATE [ChangeControls]
           SET  [ChangeControl_Name] = @ChangeControl_Name
	           ,[Group_Name] = @Group_Name
	           ,[Description_Text] = @Description_Text
	           ,[Principal_Name] = @Principal_Name
	           ,[PrincipalType_Code] = @PrincipalType_Code
	           ,[PerformanceType_Code] = @PerformanceType_Code
	           ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
	           ,[ModifiedOn_Date] = GETUTCDATE()
	           ,[Active_Indicator] = @Active_Indicator
	     WHERE [ChangeControl_Id] = @ChangeControl_Id
	     
	     DELETE [ChangeControlEnvironments]
		 WHERE [ChangeControl_Id] = @ChangeControl_Id
        
         INSERT INTO [ChangeControlEnvironments] ([ChangeControl_Id], [Environment_Id])
	     SELECT
			    @ChangeControl_Id,
			    CAST(CSV.[Value_Text] AS INT)
	      FROM [dbo].[CsvToTable](@Environments_Csv, ',') CSV
	     
	     EXEC [Events_RaiseEvent] 'CCTMOD', @Application_Id, @ChangeControl_Id
    
    END

COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ChangeControls_CreateOrUpdateChangeControl] TO [BuildMasterUser_Role]
