EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_FailExecutingPlans',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Stored procedure for internal use only.'
GO


IF OBJECT_ID('[Executions_FailExecutingPlans]') IS NOT NULL DROP PROCEDURE [Executions_FailExecutingPlans]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_FailExecutingPlans]
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	EXEC [Events_RaiseEvent] 'EXEFAL', NULL

	/* Fail all promotions */
	UPDATE [BuildPromotions]
	   SET [PromotionStatus_Name] = 'Failed'
	  FROM [BuildPromotions] BP
	       INNER JOIN [BuildExecutions] BE
	               ON BE.[Promotion_Id] = BP.[Promotion_Id]
		   INNER JOIN [Executions] E
		           ON E.[Execution_Id] = BE.[Execution_Id]
	 WHERE E.[ExecutionRunState_Code] = 'X'

	/* Fail all actions */
	UPDATE [BuildExecution_ActionGroupActions]
	   SET [ExecutionStatus_Name] = 'Failed',
	       [ExecutionEnded_Date] = GETUTCDATE()
	 WHERE [ExecutionStatus_Name] IN ('Executing', 'Canceled')

	UPDATE [Executions]
	   SET [ExecutionRunState_Code] = 'C',
	       [ExecutionStatus_Code] = 'E',
		   [End_Date] = GETUTCDATE()
	 WHERE [ExecutionRunState_Code] = 'X'

	/* Kill all manual actions */
	DELETE [ManualActionsInProgress]

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH		 


END
GO

GRANT EXECUTE ON [Executions_FailExecutingPlans] TO [BuildMasterUser_Role]