EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_DeleteAction',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes an action from an action group.'
GO


IF OBJECT_ID('[Plans_DeleteAction]') IS NOT NULL DROP PROCEDURE [Plans_DeleteAction]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_DeleteAction]
(
	@DeploymentPlanActionGroup_Id INT,
	@Action_Sequence INT
)
AS
BEGIN

	DECLARE @ActionGroup_Id INT
	    SET @ActionGroup_Id = (SELECT [ActionGroup_Id]
	                             FROM [DeploymentPlanActionGroups]
	                            WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id)

	IF NOT EXISTS(SELECT * FROM [ActionGroupActions] WHERE [ActionGroup_Id] = @ActionGroup_Id AND [Action_Sequence] = @Action_Sequence)
	BEGIN
		/* Silently Return */
		RETURN;
	END

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	-- move action to the end of the sequence before deletion to appease trigger
    DECLARE @New_Action_Sequence INT
    SELECT @New_Action_Sequence = MAX([Action_Sequence])
      FROM [ActionGroupActions]
     WHERE [ActionGroup_Id] = @ActionGroup_Id

	UPDATE [ActionGroupActions]
	   SET [Action_Sequence] = CASE
	          WHEN [ActionGroupActions].[Action_Sequence] = CUR.[Action_Sequence] 
	               THEN NEW.[Action_Sequence]
	          WHEN [ActionGroupActions].[Action_Sequence] BETWEEN CUR.[Action_Sequence] AND NEW.[Action_Sequence]
	               THEN [ActionGroupActions].[Action_Sequence] - 1
	          WHEN [ActionGroupActions].[Action_Sequence] BETWEEN NEW.[Action_Sequence] AND CUR.[Action_Sequence]
	               THEN [ActionGroupActions].[Action_Sequence] + 1
	          ELSE [ActionGroupActions].[Action_Sequence]
	          END
	  FROM [ActionGroupActions],
	       [ActionGroupActions] CUR,
	       [ActionGroupActions] NEW
	 WHERE CUR.[Action_Sequence] = @Action_Sequence
	   AND NEW.[Action_Sequence] = @New_Action_Sequence
	   AND @Action_Sequence <> @New_Action_Sequence
	   AND [ActionGroupActions].[ActionGroup_Id] = @ActionGroup_Id
	   AND CUR.[ActionGroup_Id] = @ActionGroup_Id
	   AND NEW.[ActionGroup_Id] = @ActionGroup_Id

	-- delete the action now that it's at the end
	DELETE [ActionGroupActions]
	WHERE [ActionGroup_Id] = @ActionGroup_Id
	  AND [Action_Sequence] = @New_Action_Sequence
	  
	DECLARE @Plans TABLE ([DeploymentPlan_Id] INT)
	INSERT INTO @Plans
	SELECT DISTINCT([DeploymentPlan_Id])
	  FROM [DeploymentPlanActionGroups]
	 WHERE [ActionGroup_Id] = @ActionGroup_Id
 
	WHILE ((SELECT COUNT(*) FROM @Plans) > 0)
	BEGIN

		DECLARE @DeploymentPlan_Id INT
		SET @DeploymentPlan_Id = (SELECT TOP 1 [DeploymentPlan_Id] FROM @Plans)
		DELETE @Plans WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

		EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	END

	UPDATE [ActionGroups]
	   SET [ModifiedOn_Date] = GETUTCDATE(),
	       [ModifiedBy_User_Name] = dbo.Session_GetUserName()
	 WHERE [ActionGroup_Id] = @ActionGroup_Id

	-- disable reexecution for anything that used the plan containing the action group
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
		                        FROM [BuildExecution_DeploymentPlans] BEDP
		                             INNER JOIN [DeploymentPlanActionGroups] DPAG
		                                     ON DPAG.[DeploymentPlan_Id] = BEDP.[Original_DeploymentPlan_Id]
		                       WHERE DPAG.[ActionGroup_Id] = @ActionGroup_Id)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH
END
GO

GRANT EXECUTE ON [Plans_DeleteAction] TO [BuildMasterUser_Role]
