EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_ResequenceActionGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Changes the sequence of a deployment plan action group.'
GO


IF OBJECT_ID('[Plans_ResequenceActionGroup]') IS NOT NULL DROP PROCEDURE [Plans_ResequenceActionGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_ResequenceActionGroup]
(
	@DeploymentPlanActionGroup_Id INT,
	@New_DeploymentPlanActionGroup_Sequence INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

    DECLARE @DeploymentPlanActionGroup_Sequence INT
    DECLARE @ActionGroup_Id INT
	DECLARE @DeploymentPlan_Id INT

	SELECT @DeploymentPlan_Id = [DeploymentPlan_Id],
	       @ActionGroup_Id = [ActionGroup_Id],
	       @DeploymentPlanActionGroup_Sequence = [DeploymentPlanActionGroup_Sequence]
	  FROM [DeploymentPlanActionGroups]
	 WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

	BEGIN TRANSACTION

	UPDATE [DeploymentPlanActionGroups]
	   SET [DeploymentPlanActionGroup_Sequence] = CASE
	          WHEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] = CUR.[DeploymentPlanActionGroup_Sequence] 
	               THEN NEW.[DeploymentPlanActionGroup_Sequence]
	          WHEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] BETWEEN CUR.[DeploymentPlanActionGroup_Sequence] AND NEW.[DeploymentPlanActionGroup_Sequence]
	               THEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] - 1
	          WHEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] BETWEEN NEW.[DeploymentPlanActionGroup_Sequence] AND CUR.[DeploymentPlanActionGroup_Sequence]
	               THEN [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence] + 1
	          ELSE [DeploymentPlanActionGroups].[DeploymentPlanActionGroup_Sequence]
	          END
	  FROM [DeploymentPlanActionGroups],
	       [DeploymentPlanActionGroups] CUR,
	       [DeploymentPlanActionGroups] NEW
	 WHERE CUR.[DeploymentPlanActionGroup_Sequence] = @DeploymentPlanActionGroup_Sequence
	   AND NEW.[DeploymentPlanActionGroup_Sequence] = @New_DeploymentPlanActionGroup_Sequence
	   AND @DeploymentPlanActionGroup_Sequence <> @New_DeploymentPlanActionGroup_Sequence
	   AND [DeploymentPlanActionGroups].[DeploymentPlan_Id] = @DeploymentPlan_Id
	   AND CUR.[DeploymentPlan_Id] = @DeploymentPlan_Id
	   AND NEW.[DeploymentPlan_Id] = @DeploymentPlan_Id

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

 	-- disable reexecution for anything that used the modified plan
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
	                            FROM [BuildExecution_DeploymentPlans] BEDP
	                           WHERE BEDP.[Original_DeploymentPlan_Id] = @DeploymentPlan_Id)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_ResequenceActionGroup] TO [BuildMasterUser_Role]