EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Providers_DeleteProvider',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes the specified provider'
GO


IF OBJECT_ID('[Providers_DeleteProvider]') IS NOT NULL DROP PROCEDURE [Providers_DeleteProvider]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Providers_DeleteProvider]
(
	@Provider_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @ProviderType_Code CHAR(1), @Provider_Name SQL_VARIANT
		SELECT @Provider_Name = [Provider_Name],
			   @ProviderType_Code = [ProviderType_Code]
		  FROM [Providers]
		 WHERE [Provider_Id] = @Provider_Id

	IF @ProviderType_Code = 'B' BEGIN
		RAISERROR('Database providers may not be deleted with this procedure.', 16, 1)
		END

	ELSE IF @ProviderType_Code = 'I' BEGIN
		UPDATE [Applications] 
		   SET [IssueTracking_Provider_Id] = NULL
		 WHERE [IssueTracking_Provider_Id] = @Provider_Id
		END
	
	ELSE IF @ProviderType_Code = 'S' BEGIN
		DELETE [BuildSchedules]
		 WHERE [SourceControl_Provider_Id] = @Provider_Id
		END

	ELSE IF @ProviderType_Code IS NOT NULL BEGIN
		RAISERROR('Deleting Provider type %s is not be supported.', 16, 1, @ProviderType_Code)
		END

	DELETE [Providers]
	 WHERE [Provider_Id] = @Provider_Id

	IF @@ROWCOUNT>0
	EXEC [Events_RaiseEvent] 'PVDDEL', NULL, @Provider_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Providers_DeleteProvider] TO [BuildMasterUser_Role]
