EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_CancelRelease',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Cancels the specified release.'
GO


IF OBJECT_ID('[Releases_CancelRelease]') IS NOT NULL DROP PROCEDURE [Releases_CancelRelease]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_CancelRelease]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@CancelledReason_Text VARCHAR(500)
)
AS
BEGIN

SET NOCOUNT ON

	IF EXISTS(SELECT * 
	            FROM [Releases] 
			   WHERE [Application_Id] = @Application_Id
                 AND [Release_Number] = @Release_Number
			     AND [ReleaseStatus_Name] IN ('Deployed', 'Cancelled'))
	BEGIN
		RETURN
	END



BEGIN TRY
	BEGIN TRANSACTION


    UPDATE B
       SET B.[BuildStatus_Name] = 'Rejected'
          ,B.[RejectedBy_User_Name] = dbo.Session_GetUserName()
          ,B.[Rejected_Date] = GETUTCDATE()
          ,B.[Rejection_Notes] = 'Release was cancelled'
	  FROM [Builds] B
	       INNER JOIN [Releases] R
		           ON R.[Release_Id] = B.[Release_Id]
     WHERE R.[Application_Id] = @Application_Id
       AND R.[Release_Number] = @Release_Number
       AND B.[BuildStatus_Name] <> 'Rejected'
	 
    UPDATE [Releases]
       SET [ReleaseStatus_Name] = 'Cancelled',
		   [CancelledBy_User_Name] = dbo.Session_GetUserName(),
		   [CancelledReason_Text] = @CancelledReason_Text,
           [CancelledOn_Date] = GETUTCDATE()
     WHERE [Application_Id] = @Application_Id
       AND [Release_Number] = @Release_Number

	EXEC [Events_RaiseEvent] 'RELCNL', @Application_Id, @Release_Number

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Releases_CancelRelease] TO [BuildMasterUser_Role]
